---
title: "Urubu 0.8 released"
layout: page 
date: 2015-11-22
---

Release highlights:

* the `urubu` serve command automatically takes
the `baseurl` option into account (Pull request #27).

* when an undefined anchor is referred to in a page, a
warning is generated, just like for references to undefined pages (Issue #30).

* the `layout` attribute can be assigned `null`. In this
way the page content can be used by other pages, but no html is generated for
the page itself.

In addition, a significant effort was put into development robustness. In
particular, a regression test suite has been added. This is based on `py.test`
and `tox`, so that both Python 2.7 and 3.4 are verified. 


